==> blancoCharacterGroup-0.1.6-src.zip: blancoCharacterGroup/blanco.cs/main/blanco/sample/charactergroup/SampleHanKatakanaCharacterGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.charactergroup
{
    /// <summary>pJ^JĩTvBblancoCharacterGroup̎ɂ͉e܂B</summary>
    public class SampleHanKatakanaCharacterGroup
    {
        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public bool Match(char argCheck)
        {
            // No.2
            // :a1: Ǔ_
            // 0xa1 (Windows-31J)
            // 0xff61 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.3
            // :a2: p̃JMJbRB
            // 0xa2 (Windows-31J)
            // 0xff62 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.4
            // :a3: p̃JMJbRB
            // 0xa3 (Windows-31J)
            // 0xff63 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.5
            // :a4: Ǔ_
            // 0xa4 (Windows-31J)
            // 0xff64 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.6
            // :a5: p̒
            // 0xa5 (Windows-31J)
            // 0xff65 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.8
            // :a7: J^JiB@B
            // 0xa7 (Windows-31J)
            // 0xff67 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.9
            // :a8: J^Ji
            // 0xa8 (Windows-31J)
            // 0xff68 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.10
            // :a9: J^Ji
            // 0xa9 (Windows-31J)
            // 0xff69 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.11
            // :aa: J^Ji
            // 0xaa (Windows-31J)
            // 0xff6a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.12
            // :ab: J^Ji
            // 0xab (Windows-31J)
            // 0xff6b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.13
            // :ac: J^Ji
            // 0xac (Windows-31J)
            // 0xff6c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.14
            // :ad: J^Ji
            // 0xad (Windows-31J)
            // 0xff6d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.15
            // :ae: J^JiBB
            // 0xae (Windows-31J)
            // 0xff6e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.16
            // :af: J^JiBbB̎ɒ`Ă܂B
            // 0xaf (Windows-31J)
            // 0xff6f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.17
            // :b0: p̐L΂B|B
            // 0xb0 (Windows-31J)
            // 0xff70 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.18
            // :b1: J^JiBAB
            // 0xb1 (Windows-31J)
            // 0xff71 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.19
            // :b2: J^Ji
            // 0xb2 (Windows-31J)
            // 0xff72 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.20
            // :b3: J^Ji
            // 0xb3 (Windows-31J)
            // 0xff73 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.21
            // :b4: J^Ji
            // 0xb4 (Windows-31J)
            // 0xff74 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.22
            // :b5: J^Ji
            // 0xb5 (Windows-31J)
            // 0xff75 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.23
            // :b6: J^Ji
            // 0xb6 (Windows-31J)
            // 0xff76 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.24
            // :b7: J^Ji
            // 0xb7 (Windows-31J)
            // 0xff77 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.25
            // :b8: J^Ji
            // 0xb8 (Windows-31J)
            // 0xff78 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.26
            // :b9: J^Ji
            // 0xb9 (Windows-31J)
            // 0xff79 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.27
            // :ba: J^Ji
            // 0xba (Windows-31J)
            // 0xff7a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.28
            // :bb: J^Ji
            // 0xbb (Windows-31J)
            // 0xff7b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.29
            // :bc: J^Ji
            // 0xbc (Windows-31J)
            // 0xff7c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.30
            // :bd: J^Ji
            // 0xbd (Windows-31J)
            // 0xff7d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.31
            // :be: J^Ji
            // 0xbe (Windows-31J)
            // 0xff7e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.32
            // :bf: J^Ji
            // 0xbf (Windows-31J)
            // 0xff7f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.33
            // :c0: J^Ji
            // 0xc0 (Windows-31J)
            // 0xff80 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.34
            // :c1: J^Ji
            // 0xc1 (Windows-31J)
            // 0xff81 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.35
            // :c2: J^Ji
            // 0xc2 (Windows-31J)
            // 0xff82 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.36
            // :c3: J^Ji
            // 0xc3 (Windows-31J)
            // 0xff83 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.37
            // :c4: J^Ji
            // 0xc4 (Windows-31J)
            // 0xff84 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.38
            // :c5: J^Ji
            // 0xc5 (Windows-31J)
            // 0xff85 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.39
            // :c6: J^Ji
            // 0xc6 (Windows-31J)
            // 0xff86 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.40
            // :c7: J^Ji
            // 0xc7 (Windows-31J)
            // 0xff87 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.41
            // :c8: J^Ji
            // 0xc8 (Windows-31J)
            // 0xff88 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.42
            // :c9: J^Ji
            // 0xc9 (Windows-31J)
            // 0xff89 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.43
            // :ca: J^Ji
            // 0xca (Windows-31J)
            // 0xff8a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.44
            // :cb: J^Ji
            // 0xcb (Windows-31J)
            // 0xff8b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.45
            // :cc: J^Ji
            // 0xcc (Windows-31J)
            // 0xff8c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.46
            // :cd: J^Ji
            // 0xcd (Windows-31J)
            // 0xff8d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.47
            // :ce: J^Ji
            // 0xce (Windows-31J)
            // 0xff8e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.48
            // :cf: J^Ji
            // 0xcf (Windows-31J)
            // 0xff8f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.49
            // :d0: J^Ji
            // 0xd0 (Windows-31J)
            // 0xff90 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.50
            // :d1: J^Ji
            // 0xd1 (Windows-31J)
            // 0xff91 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.51
            // :d2: J^Ji
            // 0xd2 (Windows-31J)
            // 0xff92 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.52
            // :d3: J^Ji
            // 0xd3 (Windows-31J)
            // 0xff93 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.53
            // :d4: J^Ji
            // 0xd4 (Windows-31J)
            // 0xff94 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.54
            // :d5: J^Ji
            // 0xd5 (Windows-31J)
            // 0xff95 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.55
            // :d6: J^Ji
            // 0xd6 (Windows-31J)
            // 0xff96 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.56
            // :d7: J^Ji
            // 0xd7 (Windows-31J)
            // 0xff97 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.57
            // :d8: J^Ji
            // 0xd8 (Windows-31J)
            // 0xff98 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.58
            // :d9: J^Ji
            // 0xd9 (Windows-31J)
            // 0xff99 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.59
            // :da: J^Ji
            // 0xda (Windows-31J)
            // 0xff9a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.60
            // :db: J^Ji
            // 0xdb (Windows-31J)
            // 0xff9b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.61
            // :dc: J^JiBB
            // 0xdc (Windows-31J)
            // 0xff9c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.62
            // :a6: J^JiBBMS932ɂR[hƂĂ AOɈʒu܂B
            // 0xa6 (Windows-31J)
            // 0xff66 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.63
            // :dd: J^JiBB
            // 0xdd (Windows-31J)
            // 0xff9d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.64
            // :de: 
            // 0xde (Windows-31J)
            // 0xff9e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.65
            // :df: 
            // 0xdf (Windows-31J)
            // 0xff9f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            return false;
        }

        /// <summary>^ꂽ񂪁ASĕO[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>SĂ̕O[vɊ܂܂ĂtureBO[vɊ܂܂Ȃ܂܂ĂfalseB</returns>
        public bool MatchAll(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAll]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index]) == false) {
                    return false;
                }
            }
            return true;
        }

        /// <summary>^ꂽ񂪁AO[vɊ܂܂镶ЂƂł܂ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂Ă镶ЂƂł܂łtureBO[vɊ܂܂镶ЂƂ܂܂ȂꍇfalseB</returns>
        public bool MatchAny(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAny]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index])) {
                    return true;
                }
            }
            return false;
        }
    }
}

==> blancoCharacterGroup-0.2.1-src.zip: blancoCharacterGroup/blanco.cs/main/blanco/sample/charactergroup/SampleHanKatakanaCharacterGroup.cs <==
// ̃\[XR[h blanco FrameworkɂĎĂ܂B
using System;

namespace blanco.sample.charactergroup
{
    /// <summary>pJ^JĩTvBblancoCharacterGroup̎ɂ͉e܂B</summary>
    public class SampleHanKatakanaCharacterGroup
    {
        /// <summary>O[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB</returns>
        public virtual bool Match(char argCheck)
        {
            // No.2
            // :a1: Ǔ_
            // 0xa1 (Windows-31J)
            // 0xff61 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.3
            // :a2: p̃JMJbRB
            // 0xa2 (Windows-31J)
            // 0xff62 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.4
            // :a3: p̃JMJbRB
            // 0xa3 (Windows-31J)
            // 0xff63 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.5
            // :a4: Ǔ_
            // 0xa4 (Windows-31J)
            // 0xff64 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.6
            // :a5: p̒
            // 0xa5 (Windows-31J)
            // 0xff65 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.8
            // :a7: J^JiB@B
            // 0xa7 (Windows-31J)
            // 0xff67 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.9
            // :a8: J^Ji
            // 0xa8 (Windows-31J)
            // 0xff68 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.10
            // :a9: J^Ji
            // 0xa9 (Windows-31J)
            // 0xff69 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.11
            // :aa: J^Ji
            // 0xaa (Windows-31J)
            // 0xff6a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.12
            // :ab: J^Ji
            // 0xab (Windows-31J)
            // 0xff6b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.13
            // :ac: J^Ji
            // 0xac (Windows-31J)
            // 0xff6c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.14
            // :ad: J^Ji
            // 0xad (Windows-31J)
            // 0xff6d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.15
            // :ae: J^JiBB
            // 0xae (Windows-31J)
            // 0xff6e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.16
            // :af: J^JiBbB̎ɒ`Ă܂B
            // 0xaf (Windows-31J)
            // 0xff6f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.17
            // :b0: p̐L΂B|B
            // 0xb0 (Windows-31J)
            // 0xff70 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.18
            // :b1: J^JiBAB
            // 0xb1 (Windows-31J)
            // 0xff71 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.19
            // :b2: J^Ji
            // 0xb2 (Windows-31J)
            // 0xff72 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.20
            // :b3: J^Ji
            // 0xb3 (Windows-31J)
            // 0xff73 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.21
            // :b4: J^Ji
            // 0xb4 (Windows-31J)
            // 0xff74 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.22
            // :b5: J^Ji
            // 0xb5 (Windows-31J)
            // 0xff75 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.23
            // :b6: J^Ji
            // 0xb6 (Windows-31J)
            // 0xff76 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.24
            // :b7: J^Ji
            // 0xb7 (Windows-31J)
            // 0xff77 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.25
            // :b8: J^Ji
            // 0xb8 (Windows-31J)
            // 0xff78 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.26
            // :b9: J^Ji
            // 0xb9 (Windows-31J)
            // 0xff79 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.27
            // :ba: J^Ji
            // 0xba (Windows-31J)
            // 0xff7a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.28
            // :bb: J^Ji
            // 0xbb (Windows-31J)
            // 0xff7b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.29
            // :bc: J^Ji
            // 0xbc (Windows-31J)
            // 0xff7c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.30
            // :bd: J^Ji
            // 0xbd (Windows-31J)
            // 0xff7d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.31
            // :be: J^Ji
            // 0xbe (Windows-31J)
            // 0xff7e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.32
            // :bf: J^Ji
            // 0xbf (Windows-31J)
            // 0xff7f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.33
            // :c0: J^Ji
            // 0xc0 (Windows-31J)
            // 0xff80 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.34
            // :c1: J^Ji
            // 0xc1 (Windows-31J)
            // 0xff81 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.35
            // :c2: J^Ji
            // 0xc2 (Windows-31J)
            // 0xff82 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.36
            // :c3: J^Ji
            // 0xc3 (Windows-31J)
            // 0xff83 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.37
            // :c4: J^Ji
            // 0xc4 (Windows-31J)
            // 0xff84 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.38
            // :c5: J^Ji
            // 0xc5 (Windows-31J)
            // 0xff85 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.39
            // :c6: J^Ji
            // 0xc6 (Windows-31J)
            // 0xff86 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.40
            // :c7: J^Ji
            // 0xc7 (Windows-31J)
            // 0xff87 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.41
            // :c8: J^Ji
            // 0xc8 (Windows-31J)
            // 0xff88 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.42
            // :c9: J^Ji
            // 0xc9 (Windows-31J)
            // 0xff89 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.43
            // :ca: J^Ji
            // 0xca (Windows-31J)
            // 0xff8a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.44
            // :cb: J^Ji
            // 0xcb (Windows-31J)
            // 0xff8b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.45
            // :cc: J^Ji
            // 0xcc (Windows-31J)
            // 0xff8c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.46
            // :cd: J^Ji
            // 0xcd (Windows-31J)
            // 0xff8d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.47
            // :ce: J^Ji
            // 0xce (Windows-31J)
            // 0xff8e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.48
            // :cf: J^Ji
            // 0xcf (Windows-31J)
            // 0xff8f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.49
            // :d0: J^Ji
            // 0xd0 (Windows-31J)
            // 0xff90 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.50
            // :d1: J^Ji
            // 0xd1 (Windows-31J)
            // 0xff91 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.51
            // :d2: J^Ji
            // 0xd2 (Windows-31J)
            // 0xff92 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.52
            // :d3: J^Ji
            // 0xd3 (Windows-31J)
            // 0xff93 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.53
            // :d4: J^Ji
            // 0xd4 (Windows-31J)
            // 0xff94 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.54
            // :d5: J^Ji
            // 0xd5 (Windows-31J)
            // 0xff95 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.55
            // :d6: J^Ji
            // 0xd6 (Windows-31J)
            // 0xff96 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.56
            // :d7: J^Ji
            // 0xd7 (Windows-31J)
            // 0xff97 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.57
            // :d8: J^Ji
            // 0xd8 (Windows-31J)
            // 0xff98 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.58
            // :d9: J^Ji
            // 0xd9 (Windows-31J)
            // 0xff99 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.59
            // :da: J^Ji
            // 0xda (Windows-31J)
            // 0xff9a (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.60
            // :db: J^Ji
            // 0xdb (Windows-31J)
            // 0xff9b (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.61
            // :dc: J^JiBB
            // 0xdc (Windows-31J)
            // 0xff9c (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.62
            // :a6: J^JiBBMS932ɂR[hƂĂ AOɈʒu܂B
            // 0xa6 (Windows-31J)
            // 0xff66 (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.63
            // :dd: J^JiBB
            // 0xdd (Windows-31J)
            // 0xff9d (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.64
            // :de: 
            // 0xde (Windows-31J)
            // 0xff9e (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            // No.65
            // :df: 
            // 0xdf (Windows-31J)
            // 0xff9f (UTF-16BE)
            if (argCheck == '') {
                return true;
            }
            return false;
        }

        /// <summary>^ꂽ񂪁ASĕO[vɊ܂܂镶ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>SĂ̕O[vɊ܂܂ĂtureBO[vɊ܂܂Ȃ܂܂ĂfalseB</returns>
        public virtual bool MatchAll(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAll]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index]) == false) {
                    return false;
                }
            }
            return true;
        }

        /// <summary>^ꂽ񂪁AO[vɊ܂܂镶ЂƂł܂ł邩ǂ𔻒肵܂B</summary>
        /// <param name="argCheck">`FbNsB</param>
        /// <returns>O[vɊ܂܂Ă镶ЂƂł܂łtureBO[vɊ܂܂镶ЂƂ܂܂ȂꍇfalseB</returns>
        public virtual bool MatchAny(string argCheck)
        {
            if (argCheck == null) {
                throw new ArgumentException("\bh[MatchAny]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B");
            }

            char[] arrayArg = argCheck.ToCharArray();
            int arraySize = arrayArg.Length;
            for (int index = 0; index < arraySize; index++) {
                if (Match(arrayArg[index])) {
                    return true;
                }
            }
            return false;
        }
    }
}
